/*
	Glob handling.

	This class loads, stores and then searches the glob patterns.
	
	Author: Matthew Allen <fret@memecode.com>
	Date: 5/12/2003
*/

#include "mime-types-priv.h"
#include "glob.h"

bool GlobLut::Load(char *File)
{
	bool Status = false;
	
	if (File)
	{
		char *Txt = ReadTextFile(File);
		if (Txt)
		{
			Array<char*> Lines;
			if (Lex(Lines, Txt, "\r\n"))
			{
				for (int l=0; l<Lines.Length(); l++)
				{
					if (Lines[l][0] != '#')
					{
						Glob *g = &Types[Types.Length()];
						g->MimeType = NewStr(Lines[l]);
						if (g->MimeType)
						{
							g->Pattern = strchr(g->MimeType, ':');
							if (g->Pattern) *g->Pattern++ = 0;
						}
						else
						{
							g->Pattern = 0;
						}
						
					}
				}
			}
			else
			{
				printf("%s:%i - Lex failed\n", __FILE__, __LINE__);
			}
			
			delete [] Txt;
		}
	}
	
	return Status;
}

void GlobLut::Empty()
{
	for (int i=0; i<Types.Length(); i++)
	{
		Glob *g = &Types[i];
		DeleteArray(g->MimeType);
	}
}

char *GlobLut::Lookup(char *File)
{
	if (File)
	{
		Glob *Best = 0;
		
		for (int i=0; i<Types.Length(); i++)
		{
			Glob *g = &Types[i];
			if (g->MimeType && g->Pattern)
			{
				if (MatchStr(g->Pattern, File))
				{
					// printf("Matched glob %s,%s\n", g->Pattern, File);
					if (!Best || strlen(Best->Pattern) < strlen(g->Pattern))
					{
						Best = g;
					}
				}
			}
		}
		
		if (Best)
		{
			// printf("Pattern match: %s\n", Best->MimeType);
			return NewStr(Best->MimeType);
		}
	}

	return 0;
}

